@@ -29,27 +29,43 @@
 
 
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <kglobal.h>
+
+#include <KLocalizedString>
+
+#include <KAboutData>
+#include <QApplication>
+#include <QCommandLineParser>
+#include <kdelibs4configmigrator.h>
 
 
 #include "kbbmainwindow.h"
-
+#include <KDBusService>
 
 
 int main( int argc, char **argv )
 {
-	KAboutData aboutData( "kblackbox", 0, ki18n("KBlackBox"), "0.4.0", ki18n("Find the balls hidden in the black box by shooting laser beams!"), KAboutData::License_GPL, ki18n("(c) 2007, Nicolas Roffet\n(c) 1999-2000, Robert Cimrman"), KLocalizedString(), "http://games.kde.org/kblackbox" );
-	aboutData.addAuthor(ki18n("Nicolas Roffet"),ki18n("Developer of version 0.4."), "nicolas-kde@roffet.com");
-	aboutData.addAuthor(ki18n("Robert Cimrman"),ki18n("Original developer"), "cimrman3@students.zcu.cz");
-	aboutData.addCredit(ki18n("Johann Ollivier Lapeyre"), ki18n("Artist"), "johann.ollivierlapeyre@gmail.com");
-	KCmdLineArgs::init( argc, argv, &aboutData );
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("kblackbox"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("kblackboxrc"));
+    migrate.setUiFiles(QStringList() << QStringLiteral("kblackboxui.rc"));
+    migrate.migrate();
+
+    QApplication application(argc, argv);
+
+    KAboutData aboutData( QLatin1String("kblackbox"), i18n("KBlackBox"), QLatin1String("0.5.0"), i18n("Find the balls hidden in the black box by shooting laser beams!"), KAboutLicense::GPL, i18n("(c) 2007, Nicolas Roffet\n(c) 1999-2000, Robert Cimrman"), QLatin1String("http://games.kde.org/kblackbox") );
+    aboutData.addAuthor(i18n("Nicolas Roffet"),i18n("Developer of version 0.4."), QLatin1String("nicolas-kde@roffet.com"));
+    aboutData.addAuthor(i18n("Robert Cimrman"),i18n("Original developer"), QLatin1String("cimrman3@students.zcu.cz"));
+    aboutData.addCredit(i18n("Johann Ollivier Lapeyre"), i18n("Artist"), QLatin1String("johann.ollivierlapeyre@gmail.com"));
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(application);
+    aboutData.processCommandLine(&parser);
+    KDBusService service;
+
+    application.setWindowIcon(QIcon::fromTheme(QStringLiteral("kblackbox")));
 
-	KApplication application;
-	KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
 
 	if (application.isSessionRestored())
 		kRestoreMainWindows<KBBMainWindow>();
